import React from 'react';
import { render, screen } from '@testing-library/react';
import Breadcrumbs, { generateBreadcrumb } from '../../components/breadcrumbs';

const mockNavigationTree = [
  {
    title: 'Home',
    slug: '/',
    children: []
  },
  {
    title: 'Page1',
    slug: '/page1',
    children: []
  },
  {
    title: 'Page2',
    slug: '/page2',
    children: [
      {
        title: 'Page2.1',
        slug: '/page2/page2.1',
        children: []
      }
    ]
  }
]

describe('generateBreadcrumb', () => {
  it('should return breadcrumbs', () => {
    const breadcrumb = generateBreadcrumb(mockNavigationTree, '/page2/page2.1');
    expect(breadcrumb).toEqual([
      {
        title: 'Home',
        slug: '/',
      },
      {
        title: 'Page2',
        slug: '/page2'
      },
      {
        title: 'Page2.1',
        slug: '/page2/page2.1',
        active: true
      }
    ]);
  });
});

describe('Breadcrumbs', () => {

  it('should render breadcrumbs', () => {
    render(<Breadcrumbs treeData={mockNavigationTree} currentPath="/page2/page2.1/" />);
    expect(screen.getByTestId('breadcrumbs')).toBeInTheDocument();
  });

  it('should render breadcrumb links', () => {
    const { getByTestId, getAllByTestId } = render(<Breadcrumbs treeData={mockNavigationTree} currentPath="/page2/page2.1/" />);
    const breadcrumbs = getByTestId('breadcrumbs');
    const breadcrumbItems = getAllByTestId('breadcrumb-item');
    expect(breadcrumbItems).toHaveLength(3);
    expect(breadcrumbItems[0].textContent).toEqual('Home');
    expect(breadcrumbItems[1].textContent).toEqual('Page2');
    expect(breadcrumbItems[2].textContent).toEqual('Page2.1');
    expect(breadcrumbs.querySelectorAll('a')).toHaveLength(2);
    expect(breadcrumbs.querySelectorAll('a')[0].textContent).toEqual('Home');
    expect(breadcrumbs.querySelectorAll('a')[1].textContent).toEqual('Page2');
  });

  it('should remove the node from the breadcrumb if not found in children', () => {
    const { getByTestId, getAllByTestId } = render(<Breadcrumbs treeData={mockNavigationTree} currentPath="/page2/page2-not-found/" />);
    const breadcrumbs = getByTestId('breadcrumbs');
    const breadcrumbItems = getAllByTestId('breadcrumb-item');
    expect(breadcrumbItems).toHaveLength(1);
    expect(breadcrumbItems[0].textContent).toEqual('Home');
    expect(breadcrumbs.querySelectorAll('a')).toHaveLength(1);
    expect(breadcrumbs.querySelectorAll('a')[0].textContent).toEqual('Home');
  });

});
