import React from 'react';
import { render, screen } from '@testing-library/react';
import Card from '../../components/card';

describe('Card', () => {
  it('renders correctly', () => {
    render(<Card>Test</Card>);
    expect(screen.getByText('Test')).toBeInTheDocument();
  });

  it('renders with the correct variants', () => {
    // variants: 'default', 'highlighted', 'gradient'
    const { rerender } = render(<Card>Test</Card>);
    expect(screen.getByText('Test')).toHaveClass('bg-panel');

    rerender(<Card variant="highlighted">Test</Card>);
    expect(screen.getByText('Test')).toHaveClass('bg-gradient-to-r');
    expect(screen.getByText('Test')).toHaveClass('from-gradient2-from');
    expect(screen.getByText('Test')).toHaveClass('to-gradient2-to');

    rerender(<Card variant="gradient">Test</Card>);
    expect(screen.getByText('Test')).toHaveClass('bg-gradient-to-r');
    expect(screen.getByText('Test')).toHaveClass('from-gradient1-from');
    expect(screen.getByText('Test')).toHaveClass('to-gradient1-to');

    rerender(<Card shadow>Test</Card>);
    expect(screen.getByText('Test')).toHaveClass('shadow-card');

    rerender(<Card hoverable>Test</Card>);
    expect(screen.getByText('Test')).toHaveClass('hover:shadow-large');
  });

  it('renders background image', () => {
    render(<Card bgImage="https://via.placeholder.com/150" imageClasses="test-image-class">Test</Card>);
    expect(screen.getByText('Test')).toBeInTheDocument();
    expect(screen.getByText('Test').querySelector('img')).toHaveClass('test-image-class');
    expect(screen.getByText('Test').querySelector('img')).toHaveAttribute('src', 'https://via.placeholder.com/150');
  });
});
