import { generateNavigationTree, sortNavigationItems} from '../../utils/createRecursiveMenu';

const mockItems = [
  {
    title: 'Home',
    slug: '/',
    fileName: 'index.mdx'
  },
  {
    title: 'Route1',
    slug: '/route1',
    fileName: 'route1/index.mdx'
  },
  {
    title: 'Subpage',
    slug: '/route1/subpage',
    fileName: 'route1/subpage.mdx'
  }
];

describe('generateNavigationTree', () => {
  it('should return an array of objects', () => {
    const result = generateNavigationTree(mockItems);
    expect(result).toBeInstanceOf(Array);
    expect(result[0]).toBeInstanceOf(Object);
  });

  it('should return an array of objects with the correct structure', () => {
    const result = generateNavigationTree(mockItems);
    expect(result[0]).toHaveProperty('title');
    expect(result[0]).toHaveProperty('slug');
    expect(result[0]).toHaveProperty('children');
  });

  it('should return an array of objects with the correct content', () => {
    const result = generateNavigationTree(mockItems);
    expect(result[0].title).toBe('Home');
    expect(result[0].slug).toBe('/');
    expect(result[0].children).toBeInstanceOf(Array);

    expect(result[1].title).toBe('Route1');
    expect(result[1].slug).toBe('/route1');
    expect(result[1].children).toBeInstanceOf(Array);

    expect(result[1].children[0].title).toBe('Subpage');
    expect(result[1].children[0].slug).toBe('/route1/subpage');
  });
});

describe('sortNavigationItems', () => {
  it('should sort the navigation items by fileName', () => {
    const result = sortNavigationItems(mockItems);
    expect(result[0].fileName).toBe('index.mdx');
    expect(result[1].fileName).toBe('route1/index.mdx');
    expect(result[2].fileName).toBe('route1/subpage.mdx');
  });
});
