import * as React from 'react';
import Header from './header';
import TableOfContents from './toc';
import Sidebar from './sidebar';
import Footer from './footer';
import { useMobileNavigation } from '../hooks/useMobileNavigation';
import Breadcrumbs from './breadcrumbs';

const Layout = ({ children, location, currentSlug, sidebarEnabled = true, tocEnabled = true, treeData = [], metaData = { themeConfig: {}} }) => {
  const slug = currentSlug ?? '/';
  const isFrontPage = slug === '/';
  const [isMobileNavOpen, toggleMobileNav] = useMobileNavigation();

  const { title, themeConfig: { useLegacyUrls, showFullNavigation } } = metaData;

  let currentNavigationBranch = `/${slug.split('/')[0]}`;
  if (useLegacyUrls) {
    currentNavigationBranch = slug === '/' ? slug : `/${slug.split('/')[0]}/index.html`;
  }
  if (showFullNavigation) {
    currentNavigationBranch = '/';
  }

  return (
    <div className="min-h-screen flex flex-col pt-16 md:pt-0">
      <Header siteTitle={title || 'Title'} isMobileNavOpen={isMobileNavOpen} toggleMobileNav={toggleMobileNav} navigation={treeData} />
      <div className="relative mx-auto flex w-full max-w-screen-2xl justify-center sm:px-2 lg:px-8 xl:px-12">
        <Sidebar branch={currentNavigationBranch} isMobileNavOpen={isMobileNavOpen} treeData={treeData} sidebarEnabled={sidebarEnabled} />
        <div className="flex-1 container max-w-3xl px-4 py-8 md:py-16 lg:max-w-none lg:pl-8 lg:pr-0 xl:px-16">
          {!isFrontPage && <Breadcrumbs treeData={treeData} currentPath={location.pathname} />}
          <main id="content">{children}</main>
        </div>
        {!isFrontPage && tocEnabled && (<TableOfContents />)}
      </div>
      <Footer>
        <div className="flex justify-center">
          <div className="px-6">
            platformOS DocsKit &copy; {new Date().getFullYear()} &mdash; powered by <a href="https://platformos.com" target="_blank" rel="noreferrer" className="underline font-bold">platformOS</a> &mdash; built with <a href="https://gatsby.com" target="_blank" rel="noreferrer">Gatsby</a>

          </div>
        </div>
      </Footer>
    </div>
  );
};

export default Layout;
