import React from 'react';
import Warning from '../images/icons/warning.svg';
import Error from '../images/icons/error.svg';
import Success from '../images/icons/success.svg';
import Info from '../images/icons/info.svg';

/**
 * tailwind
 * 'bg-highlighted bg-confirmation-disabled bg-warning-disabled bg-important-disabled'
 * 'border-highlighted border-confirmation border-warning border-important'
*/
const Message = ({
  children,
  className = '',
  variant = 'info', // info, success, warning, error
  filled = false
}) => {
  const SVGIcons = {
    info: Info,
    success: Success,
    warning: Warning,
    error: Error
  };
  const SVGsrc = SVGIcons[variant];
  const colors = {
    info: 'highlighted',
    success: 'confirmation-disabled',
    warning: 'warning-disabled',
    error: 'important-disabled'
  }
  let baseClasses = 'not-prose flex items-center gap-3 my-4 rounded-surface px-4 py-2';

  if (filled) {
    baseClasses += ` bg-${colors[variant]}`;
  } else {
    baseClasses += ` shadow-card`;
  }
  return (
    <div className={`${baseClasses} ${className}`}>
      <img src={SVGsrc} alt={variant} className="w-6 h-6" />
      <div>{children}</div>
    </div>
  );
};

export default Message;
