const path = require('path');

const defaultColors = require(path.join(__dirname, './src/theme/colors'));
const defaultFonts = require(path.join(__dirname, './src/theme/fonts'));
const defaultBorders = require(path.join(__dirname, './src/theme/borders'));

function parseColor(colorName) {
  return ({ opacityVariable, opacityValue }) => {
    if (opacityValue !== undefined) {
      return `rgba(var(--${colorName}, ${defaultColors[colorName]}), ${opacityValue})`;
    }
    if (opacityVariable !== undefined) {
      return `rgba(var(--${colorName}, ${defaultColors[colorName]}), var(${opacityVariable}, 1))`;
    }
    return `rgb(var(--${colorName}))`;
  };
}

/** @type {import('tailwindcss').Config} */
module.exports = {
  content: [
    path.join(__dirname, './src/components/**/*.{js,ts,jsx,tsx}'),
    path.join(__dirname, './src/pages/**/*.{js,ts,jsx,tsx}'),
    path.join(__dirname, './src/templates/**/*.{js,ts,jsx,tsx}'),
    path.join(__dirname, './docs/**/*.mdx')
  ],
  theme: {
    extend: {
      fontFamily: {
        'sans': ['var(--pos-fonts-default)', ...defaultFonts['pos-fonts-default']]
      },
      colors: {
        'prominent': parseColor('prominent'),
        'normal': parseColor('normal'),
        'supplementary': parseColor('supplementary'),
        'graphic': parseColor('graphic'),
        'inverted': parseColor('inverted'),
        'interactive-graphic': parseColor('interactive-graphic'),
        'interactive-text': parseColor('interactive-text'),
        'interactive-hover': parseColor('interactive-hover'),
        'interactive-disabled': parseColor('interactive-disabled'),
        'colorful': parseColor('colorful'),
        'colorful-hover': parseColor('colorful-hover'),
        'colorful-foreground': parseColor('colorful-foreground'),
        'colorful-supplementary': parseColor('colorful-supplementary'),
        'gradient1-from': `var(--gradient1-from, ${defaultColors['gradient1-from']})`,
        'gradient1-to': `var(--gradient1-to, ${defaultColors['gradient1-to']})`,
        'gradient2-from': `var(--gradient2-from, ${defaultColors['gradient2-from']})`,
        'gradient2-to': `var(--gradient2-to, ${defaultColors['gradient2-to']})`,
        'panel': parseColor('panel'),
        'base': parseColor('base'),
        'highlighted': parseColor('highlighted'),
        'divider': parseColor('divider'),
        'input': parseColor('input'),
        'input-border': parseColor('input-border'),
        'input-foreground': parseColor('input-foreground'),
        'button-primary': parseColor('button-primary'),
        'button-primary-hover': parseColor('button-primary-hover'),
        'button-primary-foreground': parseColor('button-primary-foreground'),
        'button-primary-foreground-hover': parseColor('button-primary-foreground-hover'),
        'button-primary-stroke': parseColor('button-primary-stroke'),
        'button-primary-stroke-hover': parseColor('button-primary-stroke-hover'),
        'button-secondary-background': parseColor('button-secondary-background'),
        'button-secondary': parseColor('button-secondary'),
        'button-secondary-hover': parseColor('button-secondary-hover'),
        'button-secondary-foreground': parseColor('button-secondary-foreground'),
        'button-secondary-foreground-hover': parseColor('button-secondary-foreground-hover'),
        'button-secondary-stroke': parseColor('button-secondary-stroke'),
        'button-secondary-stroke-hover': parseColor('button-secondary-stroke-hover'),
        'important': parseColor('important'),
        'important-hover': parseColor('important-hover'),
        'important-disabled': parseColor('important-disabled'),
        'confirmation': parseColor('confirmation'),
        'confirmation-hover': parseColor('confirmation-hover'),
        'confirmation-disabled': parseColor('confirmation-disabled'),
        'warning': parseColor('warning'),
        'warning-hover': parseColor('warning-hover'),
        'warning-disabled': parseColor('warning-disabled')
      },
      borderColor: {
        DEFAULT: parseColor('divider')
      },
      boxShadow: {
        'card': `0px 0px 5px rgba(var(--shadow, ${defaultColors['shadow']}), .1)`,
        'large': `0px 10px 30px rgba(var(--shadow, ${defaultColors['shadow']}), .3)`
      },
      borderRadius: {
        'surface': `var(--radius-surface, ${defaultBorders['radius-surface']})`,
        'button': `var(--radius-button, ${defaultBorders['radius-button']})`,
        'input': `var(--radius-input, ${defaultBorders['radius-input']})`
      },
      typography: (theme) => ({
        DEFAULT: {
          css: {
            '--tw-prose-body': theme('colors.normal'),
            '--tw-prose-headings': theme('colors.prominent'),
            '--tw-prose-lead': theme('colors.prominent'),
            '--tw-prose-links': theme('colors.interactive-text'),
            '--tw-prose-bold': theme('colors.prominent'),
            '--tw-prose-hr': theme('colors.divider'),
            '--tw-prose-quotes': theme('colors.supplementary'),
            '--tw-prose-quote-borders': theme('colors.divider'),
            a: {
              fontWeight: 400,
              textDecoration: 'none',
              '&:hover': {
                color: theme('colors.interactive-hover'),
                textDecoration: 'underline'
              }
            }
          }
        }
      })
    },
  },
  plugins: [
    require('@tailwindcss/typography')
  ]
}
